/*
 * An IR LED must be connected to Arduino PWM pin 3.
 * This code should run on any atmega328 board.
 * This code implements the LOW POWER stuff. Can be improve in a lot of ways but works great as a quick and dirty solution. 
 * 8uA @ sleep mode, good enough for 2 years or something like that. Remember to remove the ON LED and bypass the voltage regulator.
 * 
 * Great library! Thanks to the author.
 * https://github.com/z3t0/Arduino-IRremote
 * I've use the "IRrecord example" to decode the arrow keys and OK button of the TV remote control.
 * 
 */


#include <avr/sleep.h>
#include <avr/power.h>


const int led = 13;    // On board LED just for blinky "It's alive" at the begining of the sketch

//Recorded codes
const long up = 0x20DF02FD;     //up 
const long down = 0x20DF827D;     //down
const long left = 0x20DFE01F;     //left 
const long right = 0x20DF609F;     //right
const long ok = 0x20DF22DD;     // OK

const long test = 0x20DF40BF;

const int d = 120;  // delay between "button presses".

int p = 0;

#include <IRremote.h>

IRsend irsend;

void setup()
{
  noInterrupts ();        //Quick copy & paste from old code. 8uA consumption in sleep mode, not bad, like 2 years with a CR2032 battery.
  CLKPR = bit (CLKPCE);
  CLKPR = clock_div_2;    // clock @ 8 Mhz 
  interrupts ();  
    
  pinMode(led, OUTPUT);
}

void loop() {




//irsend.sendNEC(test,32); // I use a testing code to debug, VOL+ or CH+, something with on screen feedback.

for(int j = 0; j<=5 ; j++){
  digitalWrite(led,HIGH);
  delay(100);
  digitalWrite(led,LOW);
  delay(100);
  
  }

//irsend.sendNEC(test,32);


irsend.sendNEC(right,32);
delay(200);
irsend.sendNEC(ok,32);  
delay(3000);  // A long delay. The TV must refresh to the next screen.



//****************************
// The keyboard start at the "g" letter.
for(int i = 0; i<=2 ; i++){
irsend.sendNEC(right,32);
delay(d);
}  // These lines goes to the letter "k", first letter of my email address.

irsend.sendNEC(ok,32);  
delay(d);  //Hit the OK button.

//*****************************
irsend.sendNEC(up,32);  
delay(d);  

for(int i = 0; i<=3 ; i++){
irsend.sendNEC(left,32);
delay(d);
}  //r


irsend.sendNEC(ok,32);  
delay(d);  //ok

//****************************

for(int i = 0; i<=2 ; i++){
irsend.sendNEC(right,32);
delay(d);
}  //u

irsend.sendNEC(ok,32);  
delay(d);  //ok

//***************************

for(int i = 0; i<=1 ; i++){
irsend.sendNEC(left,32);
delay(d);
}  
for(int i = 0; i<=1 ; i++){
irsend.sendNEC(down,32);
delay(d);
}  //c

irsend.sendNEC(ok,32);  
delay(d);  //ok
//***************************

irsend.sendNEC(up,32);
delay(d);

irsend.sendNEC(right,32);
delay(d);
//h
irsend.sendNEC(ok,32);  
delay(d);  //ok


for(int i = 0; i<=2 ; i++){
irsend.sendNEC(right,32);
delay(d);
}  
irsend.sendNEC(up,32);  
delay(d);  //o
irsend.sendNEC(ok,32);  
delay(d);  //ok


irsend.sendNEC(up,32);  
delay(d);  


for(int i = 0; i<=3 ; i++){
irsend.sendNEC(left,32);
delay(d);
}  
irsend.sendNEC(ok,32);  
delay(d);  //ok



for(int i = 0; i<=3 ; i++){
irsend.sendNEC(down,32);
delay(130);
}  
irsend.sendNEC(ok,32);  
delay(d);  //ok


for(int i = 0; i<=1 ; i++){
irsend.sendNEC(down,32);
delay(d);
}  
irsend.sendNEC(ok,32);  
delay(d);  //ok
// END OF EMAIL ADDRESS. This sequence writes krucho5@gmail.com
delay(600);  // Another delay, wait screen update.

//********************PASSWORD********************
// Same logic of the email part. Complete here with your password sequence, I delete mine for obvious reasons.




//When you finish your password entry, call the sleepNow function.

  sleepNow(); 
  
 
}// loop end.

//Another copy & paste from old code, it works like a charm but probably some things are not really necessary.
void sleepNow()         // here we put the arduino to sleep
{
    /* Now is the time to set the sleep mode. In the Atmega8 datasheet
     * http://www.atmel.com/dyn/resources/prod_documents/doc2486.pdf on page 35
     * there is a list of sleep modes which explains which clocks and 
     * wake up sources are available in which sleep mode.
     *
     * In the avr/sleep.h file, the call names of these sleep modes are to be found:
     *
     * The 5 different modes are:
     *     SLEEP_MODE_IDLE         -the least power savings 
     *     SLEEP_MODE_ADC
     *     SLEEP_MODE_PWR_SAVE
     *     SLEEP_MODE_STANDBY
     *     SLEEP_MODE_PWR_DOWN     -the most power savings
     *
     * For now, we want as much power savings as possible, so we 
     * choose the according 
     * sleep mode: SLEEP_MODE_PWR_DOWN
     * 
     */  
    set_sleep_mode(SLEEP_MODE_PWR_DOWN);   // sleep mode is set here

    sleep_enable();          // enables the sleep bit in the mcucr register
                             // so sleep is possible. just a safety pin 

    /* Now it is time to enable an interrupt. We do it here so an 
     * accidentally pushed interrupt button doesn't interrupt 
     * our running program. if you want to be able to run 
     * interrupt code besides the sleep function, place it in 
     * setup() for example.
     * 
     * In the function call attachInterrupt(A, B, C)
     * A   can be either 0 or 1 for interrupts on pin 2 or 3.   
     * 
     * B   Name of a function you want to execute at interrupt for A.
     *
     * C   Trigger mode of the interrupt pin. can be:
     *             LOW        a low level triggers
     *             CHANGE     a change in level triggers
     *             RISING     a rising edge of a level triggers
     *             FALLING    a falling edge of a level triggers
     *
     * In all but the IDLE sleep modes only LOW can be used.
     */

 //   attachInterrupt(0,wakeUpNow, LOW); // use interrupt 0 (pin 2) and run function
                                       // wakeUpNow when pin 2 gets LOW 

    sleep_mode();            // here the device is actually put to sleep!!
                             // THE PROGRAM CONTINUES FROM HERE AFTER WAKING UP

    sleep_disable();         // first thing after waking from sleep:                            //Hace falta esto?? 
                             // disable sleep...
//    detachInterrupt(0);      // disables interrupt 0 on pin 2 so the 
                             // wakeUpNow code will not be executed 
                             // during normal running time.

}


